@@ -4,8 +4,8 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
-## ----setup, eval=FALSE, echo=FALSE--------------------------------------------
-#  library(IPEDSuploadables)
+## ----setup, include=FALSE-----------------------------------------------------
+library(IPEDSuploadables)
 
 ## ----create_data_file_in_package, eval=FALSE, echo=FALSE----------------------
 #  #this chunk is only used during interactive session by the package maintainers, if the requirements have been updated
@@ -18,8 +18,6 @@ knitr::opts_chunk$set(
 #  use_data(specs_GR200, overwrite = TRUE)
 
 ## ----specstable_df, echo=FALSE, warning=FALSE, message=FALSE------------------
-#figure out why striped isn't working when format = 'html'
-load("../data/specs_GR200.rda")
 library(magrittr)
 specs_GR200$ACCEPTABLE_VALUES <- stringr::str_replace_all(specs_GR200$ACCEPTABLE_VALUES, pattern = "\\n", replacement = "<br>")
 
